@@ -294,13 +294,6 @@ setMethod("dbListObjects", c("MariaDBConnection", "ANY"), function(conn, prefix
   ret
 })
 
-as_table <- function(schema, table, naked_table = NULL) {
-  args <- c(schema = schema, table = table, table = naked_table)
-  # Also omits NA args
-  args <- args[!is.na(args) & args != ""]
-  do.call(Id, as.list(args))
-}
-
 #' @export
 #' @rdname mariadb-tables
 setMethod("dbExistsTable", c("MariaDBConnection", "character"),
