@@ -55,3 +55,13 @@ List df_create(const std::vector<MariaFieldType>& types, const std::vector<std::
   }
   return out;
 }
+
+// From https://stackoverflow.com/a/40914871/946850:
+int days_from_civil(int y, int m, int d) {
+  y -= m <= 2;
+  const int era = (y >= 0 ? y : y - 399) / 400;
+  const int yoe = static_cast<unsigned>(y - era * 400);           // [0, 399]
+  const int doy = (153 * (m + (m > 2 ? -3 : 9)) + 2) / 5 + d - 1; // [0, 365]
+  const int doe = yoe * 365 + yoe / 4 - yoe / 100 + doy;          // [0, 146096]
+  return era * 146097 + doe - 719468;
+}
